/*
Author: Neil Spencer
Creation Date: ??/??/??
Revision 1 Date: ??/??/??
Purpose: Read Los Angeles Depression Data
*/

LIBNAME abcxyz 'a:\data';
LIBNAME library 'a:\formats';

PROC FORMAT LIBRARY=library.formats;
VALUE gendlab 1='male' 2='female';
VALUE maritlab 1='never married' 2='married' 3='divorced'
  4='separated' 5='widowed';
VALUE educlab 1='less than high school' 2='some high school'
  3='finished high school' 4='some college'
  5='finished bachelor degree' 6='finished master degree'
  7='finished doctorate';
VALUE empllab 1='full time' 2='part time' 3='unemployed' 4='retired'
  5='houseperson' 6='in school' 7='other';
VALUE religlab 1='Protestant' 2='Catholic' 3='Jewish' 4='none'
  5='other';
VALUE stmntlab 0='rarely or none of the time (less than day)'
  1='some or a little of the time (1-2 days)'
  2='occasionally or a moderate amount of the time (3-4 days)'
  3='most or all of the time (5-7 days)';
VALUE caseslab 0='normal' 1='depressed';
VALUE ynlaba 1='yes' 2='no';
VALUE hlthlab 1='excellent' 2='good' 3='fair' 4='poor';
VALUE ynlabb 0='no' 1='yes';

DATA abcxyz.depress;
INFILE 'a:\data\depress.dat';
INPUT obs id gender age marital education employment income religion
  statement1-statement20 cesd cases drink health regdoctor treat
  beddays acuteill chronicill;
LABEL obs='Observation';
LABEL id='Indentification number';
LABEL gender='Gender';
LABEL age='Age';
LABEL marital='Marital status';
LABEL education='Level of education';
LABEL employment='Employment status';
LABEL income='Income';
LABEL religion='Religion';
LABEL statement1='I felt that I could not shake off the blues even with the help of my family or friends';
LABEL statement2='I felt depressed';
LABEL statement3='I felt lonely';
LABEL statement4='I had crying spells';
LABEL statement5='I felt sad';
LABEL statement6='I felt fearful';
LABEL statement7='I thought my life had been a failure';
LABEL statement8='I felt that I was as good as other people';
LABEL statement9='I felt hopeful about the future';
LABEL statement10='I was happy';
LABEL statement11='I enjoyed life';
LABEL statement12='I was bothered by things that usually do not bother me';
LABEL statement13='I did not feel like eating; my appetite was poor';
LABEL statement14='I felt that everything was an effort';
LABEL statement15='My sleep was restless';
LABEL statement16='I could not get going';
LABEL statement17='I had trouble keeping my mind on what I was doing';
LABEL statement18='I talked less than usual';
LABEL statement19='People were unfriendly';
LABEL statement20='I felt that people disliked me';
LABEL cesd='CESD score';
LABEL cases='Cases';
LABEL drink='Regular drinker';
LABEL health='General health';
LABEL regdoctor='Have a regular doctor';
LABEL treat='Treatment recommended';
LABEL beddays='Spent entire day(s) in bed in last two months';
LABEL acuteill='Any acute illness in the last two months?';
LABEL chronicill='Any chronic illness in the last two months?';
FORMAT gender gendlab.;
FORMAT marital maritlab.;
FORMAT education educlab.;
FORMAT employment empllab.;
FORMAT religion religlab.;
FORMAT statement1-statement20 stmntlab.;
FORMAT cases caseslab.;
FORMAT drink regdoctor treat ynlaba.;
FORMAT health hlthlab.;
FORMAT beddays acuteill chronicill ynlabb.;

PROC PRINT data=abcxyz.depress;

RUN;
